==> qcad-3.15.5.3.tgz: lib/qcad/scripts/Draw/Circle/Circle2P/ts/Circle2P_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl_PL">
<context>
    <name>Circle2P</name>
    <message>
        <location filename="../Circle2P.js" line="+58"/>
        <source>First point</source>
        <translatorcomment>--google--
Wskaż pierwszy punkt
Wskaż pierwszy punkt wieloboku
Wskaż pierwszy punkt odległości</translatorcomment>
        <translation type="unfinished">Pierwszy punkt</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Second point</source>
        <translatorcomment>--google--
Wskaż drugi punkt
Wskaż dugi punkt odległości
Wskaż drugi punkt linii odbicia</translatorcomment>
        <translation type="unfinished">Drugi punkt</translation>
    </message>
    <message>
        <location line="+83"/>
        <source>The two points are identical</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Te dwa punkty są identyczne</translation>
    </message>
    <message>
        <location filename="../Circle2PInit.js" line="+2"/>
        <source>&amp;2 Points</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
&amp;2 Punkty</translatorcomment>
        <translation type="unfinished">&amp;2 Punkty</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Draw circle from 2 diametrically opposite points</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Narysuj koło z 2 diametralnie przeciwstawnych punktów</translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/Draw/Circle/Circle2P/ts/Circle2P_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>Circle2P</name>
    <message>
        <location filename="../Circle2P.js" line="+58"/>
        <source>First point</source>
        <translatorcomment>--google--
Wskaż pierwszy punkt
Wskaż pierwszy punkt wieloboku
Wskaż pierwszy punkt odległości</translatorcomment>
        <translation>Pierwszy punkt</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Second point</source>
        <translatorcomment>--google--
Wskaż drugi punkt
Wskaż dugi punkt odległości
Wskaż drugi punkt linii odbicia</translatorcomment>
        <translation>Drugi punkt</translation>
    </message>
    <message>
        <location line="+83"/>
        <source>The two points are identical</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Te dwa punkty są takie same</translation>
    </message>
    <message>
        <location filename="../Circle2PInit.js" line="+2"/>
        <source>&amp;2 Points</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
&amp;2 Punkty</translatorcomment>
        <translation>&amp;2 punkty</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Draw circle from 2 diametrically opposite points</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Rysuje okrąg przez 2 przeciwległe punkty</translation>
    </message>
</context>
</TS>
